# Allons-y - Assistant de Candidature IA

## Introduction

Bienvenue dans le projet **Allons-y - Assistant de Candidature IA** !

Cette application web a pour objectif de simplifier et d'accélérer le processus de candidature à un emploi en tirant parti de l'intelligence artificielle. Elle offre aux candidats des outils puissants pour optimiser leurs CV, lettres de motivation, et adapter leurs candidatures aux offres d'emploi.

Actuellement, nous nous concentrons sur le développement du **Backend (API)** pour établir les fondations solides de l'application, y compris l'authentification, la gestion des documents et l'intégration des fonctionnalités d'IA.

Que vous soyez un jeune diplômé ou un professionnel expérimenté en quête de nouvelles opportunités, Allons-y est conçu pour vous aider à maximiser vos chances de succès.

## Fonctionnalités Principales (MVP et Futures)

* **Analyse d'Offre (Scoring) :** Évalue la pertinence d'un CV par rapport à une offre d'emploi.
* **Génération de Paragraphe de Motivation :** Crée des paragraphes personnalisés pour les lettres de motivation.
* **Reformulation de Compétences :** Améliore la formulation des compétences sur un CV.
* **Questions d'Entretien :** Génère des questions potentielles basées sur une offre ou un secteur.
* **Mots-clés CV :** Suggère des mots-clés pertinents à inclure dans le CV.
* **Gestion de Compte Utilisateur :** Inscription, connexion, gestion de profil, historique des interactions.
* **Gestion des Documents :** Téléchargement, stockage et gestion sécurisée des CVs et lettres de motivation.
* **Accès Anonyme Limité :** Possibilité d'essayer certaines fonctionnalités sans inscription pour découvrir l'application.

## Technologies Utilisées

* **Frontend :** React.js (développement futur)
* **Backend :** Python (avec FastAPI)
* **Base de Données :** PostgreSQL
* **Intelligence Artificielle :** APIs Gemini (Google) et/ou Mistral
* **Stockage de Fichiers :** (À définir : Local pour POC, S3/GCS pour production)

## Structure du Projet

Le projet est organisé en plusieurs répertoires principaux :

* `backend/` : Contient le code source de l'API Python. **C'est le focus actuel du développement.**
* `frontend/` : Sera développé ultérieurement pour l'interface utilisateur.
* `documentation/` : Contient des documents additionnels, schémas, etc.
* `README.md` : Ce fichier.
* `ROADMAP.md` : Feuille de route du projet.
* `PRD.md` : Product Requirements Document.

## Comment Démarrer le Projet (Développement Local)

Des instructions détaillées pour lancer le backend se trouvent dans son `README.md` respectif.

### Pré-requis Généraux :

* Python 3.9+ et pip pour le backend.
* Docker et Docker Compose (recommandé pour la base de données et un environnement cohérent).

### Étapes Générales :

1.  **Cloner le dépôt :**
    ```bash
    git clone [https://git-scm.com/book/fr/v2/Les-bases-de-Git-D%C3%A9marrer-un-d%C3%A9p%C3%B4t-Git](https://git-scm.com/book/fr/v2/Les-bases-de-Git-D%C3%A9marrer-un-d%C3%A9p%C3%B4t-Git)
    cd allons_y
    ```
2.  **Configuration des variables d'environnement :**
    * Copiez le fichier `.env.example` en `.env` dans le répertoire `backend/`.
    * Renseignez les valeurs nécessaires (clés API, identifiants DB, etc.).
3.  **Lancer la base de données (PostgreSQL) :**
    * (Si Docker est utilisé) Créez un `docker-compose.yml` à la racine pour la base de données, puis utilisez `docker-compose up -d postgres`.
4.  **Lancer le Backend :**
    ```bash
    cd backend
    pip install -r requirements.txt
    uvicorn main:app --reload # ou commande FastAPI équivalente
    ```
    Consultez `backend/README.md` pour plus de détails.

## Contributions

Les contributions sont les bienvenues ! Veuillez consulter les `ROADMAP.md` et `PRD.md` pour comprendre la vision et les exigences du projet.

## Licence

Ce projet est sous licence MIT.

---