import os
import sys
from logging.config import fileConfig

from sqlalchemy import engine_from_config
from sqlalchemy import pool

from alembic import context

# Ceci ajoute le répertoire 'backend' (où se trouve 'alembic.ini' et 'main.py')
# au chemin de recherche Python, permettant d'importer vos modules.
sys.path.append(os.path.abspath("."))

# Importez votre objet Base de core.database
from core.database import Base

# Importez tous vos modèles SQLAlchemy ici pour qu'Alembic puisse les détecter.
from models import user
from models import document

# this is the Alembic Config object, which provides
# access to values within the .ini file in use.
config = context.config

# Interpret the config file for Python logging.
# This line sets up loggers basically.
if config.config_file_name is not None:
    fileConfig(config.config_file_name)

# add your model's MetaData object here
# for 'autogenerate' support
# from myapp import Base
# target_metadata = Base.metadata
target_metadata = Base.metadata

# other values from the config, defined by the needs of env.py,
# can be acquired a number of ways.
# in this example, we want to override the sqlalchemy.url from the ini file
# if a DATABASE_URL environment variable is present.
# Note: config.get_main_option() reads from alembic.ini, which we updated.
url = os.environ.get("DATABASE_URL") or config.get_main_option("sqlalchemy.url")
if url:
    config.set_main_option("sqlalchemy.url", url)

def run_migrations_offline() -> None:
    """Run migrations in 'offline' mode.

    This configures the context with just a URL
    and not an actual DBAPI connection.  By doing this,
    migrations can be run without a database present.
    Methods can be called instead to produce a string
    of content to be executed later,
    e.g. env.py's Alembic.configure with a SQLAlchemy connection string.

    """
    context.configure(
        url=url,
        target_metadata=target_metadata,
        literal_binds=True,
        dialect_opts={"paramstyle": "named"},
    )

    with context.begin_transaction():
        context.run_migrations()

def run_migrations_online() -> None:
    """Run migrations in 'online' mode.

    In this scenario we need to create a connection
    to the database before configuring Alembic.

    """
    connectable = engine_from_config(
        config.get_section(config.config_ini_section, {}),
        prefix="sqlalchemy.",
        poolclass=pool.NullPool,
    )

    with connectable.connect() as connection:
        context.configure(
            connection=connection, target_metadata=target_metadata
        )

        with context.begin_transaction():
            context.run_migrations()

if context.is_offline_mode():
    run_migrations_offline()
else:
    run_migrations_online()