# ROADMAP - Allons-y Assistant de Candidature IA

Ce document décrit la feuille de route du projet Allons-y Assistant de Candidature IA, décomposée en phases pour une implémentation progressive. Il servira de guide pour le développement et la priorisation des fonctionnalités.

## Vision Générale

Rendre le processus de candidature plus efficace et accessible grâce à l'IA, en fournissant des outils intuitifs pour l'optimisation des documents et l'adaptation aux offres d'emploi.

## Phases de Développement

### Phase 1 : Minimum Viable Product (MVP) - (Focus sur l'Essentiel et la Découverte)

**Objectif :** Valider le concept principal avec les fonctionnalités IA les plus critiques et permettre une première prise en main de l'application, même sans inscription.

* **Frontend :**
    * Page d'accueil simple avec CTA pour l'inscription/connexion et l'essai anonyme.
    * Interface pour l'**Analyse d'Offre (Scoring)** :
        * Champ de texte pour coller le descriptif de poste.
        * Option d'upload temporaire d'un CV (pour l'analyse anonyme) ou sélection d'un CV déjà uploadé (pour utilisateur connecté).
        * Affichage clair du score de pertinence et des points clés d'amélioration/correspondance.
    * Pages d'Inscription et de Connexion.
    * Tableau de bord utilisateur basique (après connexion) :
        * Affichage du nom de l'utilisateur.
        * Section pour uploader un CV.
        * Accès à la fonctionnalité d'Analyse d'Offre.
    * Gestion basique des erreurs et chargements.
* **Backend :**
    * API RESTful pour l'authentification (inscription, connexion avec JWT).
    * Gestion des utilisateurs et de leurs données de base en PostgreSQL.
    * Endpoint pour l'upload de CVs (sauvegarde locale/S3, entrée en DB).
    * Endpoint pour l'**Analyse d'Offre (Scoring)** :
        * Réception du texte de l'offre et du contenu du CV (après extraction).
        * Préparation du prompt pour l'API IA (Gemini/Mistral).
        * Appel à l'API IA.
        * Traitement et renvoi du résultat formaté.
        * Gestion des interactions anonymes (limitation de requêtes par IP/session).
    * Gestion sécurisée des clés API IA et des fichiers.
    * Modèles de base de données : `User`, `File`, `AiInteraction` (simplifié pour le scoring).
* **Documentation :**
    * `README.md` (racine, frontend, backend) complétés.
    * `ROADMAP.md` (ce document).
    * `PRD.md` (détaillé pour la Phase 1).

### Phase 2 : Enrichissement des Outils IA et Expérience Utilisateur

**Objectif :** Développer les autres fonctionnalités IA clés et améliorer l'expérience utilisateur, notamment la gestion des documents et l'historique.

* **Frontend :**
    * Interface pour la **Génération de Paragraphe de Motivation**.
    * Interface pour la **Reformulation de Compétences**.
    * Interface pour les **Questions d'Entretien**.
    * Section "Mes documents" sur le tableau de bord : Lister les CVs/LMs uploadés, permettre la suppression, prévisualisation basique.
    * Page "Historique des Requêtes" pour les utilisateurs connectés.
* **Backend :**
    * Endpoints pour les nouvelles fonctionnalités IA (paragraphe, reformulation, questions).
    * Amélioration de la gestion des fichiers (URL pré-signées pour le téléchargement).
    * Enrichissement du modèle `AiInteraction` pour stocker toutes les requêtes.
    * Logique pour l'extraction de texte à partir de PDF/DOCX (si non déjà robuste).
* **Documentation :**
    * Mise à jour du `PRD.md` avec les nouvelles fonctionnalités.

### Phase 3 : Optimisation et Fonctionnalités Avancées

**Objectif :** Ajouter des outils plus spécifiques, améliorer la performance et la fiabilité, et explorer de nouvelles opportunités.

* **Frontend :**
    * Interface pour la **Génération de Mots-clés CV**.
    * Tableau de bord plus riche : statistiques d'utilisation, suggestions proactives.
    * Notifications (ex: "Votre analyse est prête").
    * Amélioration de l'UX (animations, feedback utilisateur).
* **Backend :**
    * Endpoint pour les Mots-clés CV.
    * Optimisation des appels IA (caching si pertinent, gestion des erreurs avancée).
    * Mise en place de tests d'intégration et de performance.
    * Monitoring de l'utilisation des APIs.
* **Potentiel Futur :**
    * Exportation des résultats (ex: générer une lettre de motivation complète en PDF).
    * Intégration avec des plateformes d'emploi (LinkedIn, Indeed - nécessite une étude approfondie).
    * Fonctionnalités collaboratives (partage de candidatures).
    * Modèles d'IA personnalisables (pour utilisateurs premium).
    * Interface pour la gestion des offres d'emploi suivies (comme sur le screenshot de dashboard).

---